@@ -8,7 +8,7 @@
  *	  Structs that need to be client-visible are in pqcomm.h.
  *
  *
- * Portions Copyright (c) 1996-2013, PostgreSQL Global Development Group
+ * Portions Copyright (c) 1996-2014, PostgreSQL Global Development Group
  * Portions Copyright (c) 1994, Regents of the University of California
  *
  * src/include/libpq/libpq-be.h
@@ -92,6 +92,11 @@ typedef struct
 } pg_gssinfo;
 #endif
 
+/*
+ * SSL renegotiations
+ */
+extern int	ssl_renegotiation_limit;
+
 /*
  * This is used by the postmaster in its communication with frontends.  It
  * contains all state information needed during this communication before the
@@ -126,6 +131,7 @@ typedef struct Port
 	char	   *remote_hostname;/* name (not ip addr) of remote host, if
 								 * available */
 	int			remote_hostname_resolv; /* see above */
+	int			remote_hostname_errcode;		/* see above */
 	char	   *remote_port;	/* text rep of remote port */
 	CAC_state	canAcceptConnections;	/* postmaster connection status */
 
@@ -187,9 +193,6 @@ typedef struct Port
 	char	   *peer_cn;
 	unsigned long count;
 #endif
-
-	/* This field will be in a saner place in 9.4 and up */
-	int			remote_hostname_errcode;		/* see above */
 } Port;
 
 
